import java.io.File;

import javax.xml.XMLConstants;
import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import javax.xml.validation.Validator;

import org.xml.sax.SAXException;

/**
 * This example found on
 * http://www.ibm.com/developerworks/xml/library/x-javaxmlvalidapi.html
 *
 * @author Elliotte Rusty Harold (elharo@metalab.unc.edu), Adjunct Professor, Polytechnic University
 */
public class XSDCheck1 {

	public static boolean verbose = true;

	public static String xml_filename = "validation/prova.xml";
	public static String xsd_filename = "validation/prova.xsd";

	public static void main(String[] args) 
	throws Exception {
		
		if ( args.length >= 2 ) {
			xml_filename = args[0];
			xsd_filename = args[1];
		}

		// 1. Lookup a factory for the W3C XML Schema language
		SchemaFactory factory = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
		// SchemaFactory factory = SchemaFactory.newInstance("http://www.w3.org/2001/XMLSchema");	SAME AS ABOVE
		// SchemaFactory factory = SchemaFactory.newInstance(XMLConstants.XML_DTD_NS_URI);			IF USING OBSOLETE DTD INSTEAD OF XSD 
		
		// 2. Compile the schema. 
		// Here the schema is loaded from a java.io.File, but you could use 
		// a java.net.URL or a javax.xml.transform.Source instead.
		if ( verbose ) FileUtil.printFileContent(xsd_filename);
		File schemaLocation = new File(xsd_filename);
		Schema schema = factory.newSchema(schemaLocation);
		
		// 3. Get a validator from the schema.
		Validator validator = schema.newValidator();
		
		// 4. Parse the document you want to check.
		if ( verbose ) FileUtil.printFileContent(xml_filename);
		File xmlDocument = new File(xml_filename);
		Source source = new StreamSource(xmlDocument);
		
		// 5. Check the document
		try {
		    validator.validate(source);
		    System.out.println(xml_filename + " is valid.");
		}
		catch (SAXException ex) {
		    System.out.println(xml_filename + " is not valid because ");
		    System.out.println(ex.getMessage());
		}  
	        
	}

}
